@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017 Olzhas Rakhimov
+ * Copyright (C) 2017-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
 /// @file
 /// The table model for elements.
 
-#ifndef ELEMENTCONTAINERMODEL_H
-#define ELEMENTCONTAINERMODEL_H
+#pragma once
 
 #include <cstdint>
 
@@ -34,9 +33,7 @@
 
 #include "model.h"
 
-namespace scram {
-namespace gui {
-namespace model {
+namespace scram::gui::model {
 
 /// The base class for models to list elements in a table.
 ///
@@ -216,8 +213,4 @@ protected:
     /// @}
 };
 
-} // namespace model
-} // namespace gui
-} // namespace scram
-
-#endif // ELEMENTCONTAINERMODEL_H
+} // namespace scram::gui::model
