@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017 Olzhas Rakhimov
+ * Copyright (C) 2017-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,8 +24,7 @@
 #include <QPrintDialog>
 #include <QPrintPreviewDialog>
 
-namespace scram {
-namespace gui {
+namespace scram::gui {
 
 void Printable::print()
 {
@@ -44,5 +43,4 @@ void Printable::printPreview()
     preview.exec();
 }
 
-} // namespace gui
-} // namespace scram
+} // namespace scram::gui
