@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017 Olzhas Rakhimov
+ * Copyright (C) 2017-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
 /// @file
 /// Report tree model to represent the analysis results.
 
-#ifndef REPORTTREE_H
-#define REPORTTREE_H
+#pragma once
 
 #include <vector>
 
@@ -27,8 +26,7 @@
 
 #include "src/risk_analysis.h"
 
-namespace scram {
-namespace gui {
+namespace scram::gui {
 
 /// The report is organized by its top items as analysis identifiers
 /// and its descendant items as analysis result types.
@@ -67,7 +65,4 @@ private:
     const std::vector<core::RiskAnalysis::Result> &m_results; ///< The data.
 };
 
-} // namespace gui
-} // namespace scram
-
-#endif // REPORTTREE_H
+} // namespace scram::gui
