@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017 Olzhas Rakhimov
+ * Copyright (C) 2017-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,8 +26,7 @@
 #include <QRegularExpression>
 #include <QRegularExpressionValidator>
 
-namespace scram {
-namespace gui {
+namespace scram::gui {
 
 const QValidator *Validator::name()
 {
@@ -57,5 +56,4 @@ const QValidator *Validator::nonNegative()
     return &nonNegativeValidator;
 }
 
-} // namespace gui
-} // namespace scram
+} // namespace scram::gui
