@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017 Olzhas Rakhimov
+ * Copyright (C) 2017-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,14 +18,12 @@
 /// @file
 /// Provides a GraphicsView with zoom in/out and other convenience features.
 
-#ifndef ZOOMABLEVIEW_H
-#define ZOOMABLEVIEW_H
+#pragma once
 
 #include <QGraphicsView>
 #include <QWheelEvent>
 
-namespace scram {
-namespace gui {
+namespace scram::gui {
 
 /// The base class for graphics views with default zoom logic.
 /// The zoom level is given as percents.
@@ -66,7 +64,4 @@ private:
     int m_zoom = 100; ///< The zoom level value in percents.
 };
 
-} // namespace gui
-} // namespace scram
-
-#endif // ZOOMABLEVIEW_H
+} // namespace scram::gui
