@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017 Olzhas Rakhimov
+ * Copyright (C) 2017-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,15 +18,13 @@
 /// @file
 /// Conditional (if-then-else, switch-case) expressions.
 
-#ifndef SCRAM_SRC_EXPRESSION_CONDITIONAL_H_
-#define SCRAM_SRC_EXPRESSION_CONDITIONAL_H_
+#pragma once
 
 #include <vector>
 
 #include "src/expression.h"
 
-namespace scram {
-namespace mef {
+namespace scram::mef {
 
 /// If-Then-Else ternary expression.
 class Ite : public ExpressionFormula<Ite> {
@@ -77,7 +75,4 @@ class Switch : public ExpressionFormula<Switch> {
   Expression& default_value_;  ///< The default case value.
 };
 
-}  // namespace mef
-}  // namespace scram
-
-#endif  // SCRAM_SRC_EXPRESSION_CONDITIONAL_H_
+}  // namespace scram::mef
