@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2017 Olzhas Rakhimov
+ * Copyright (C) 2014-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,15 +19,13 @@
 /// Expressions and distributions
 /// that are described with exponential formulas.
 
-#ifndef SCRAM_SRC_EXPRESSION_EXPONENTIAL_H_
-#define SCRAM_SRC_EXPRESSION_EXPONENTIAL_H_
+#pragma once
 
 #include <memory>
 
 #include "src/expression.h"
 
-namespace scram {
-namespace mef {
+namespace scram::mef {
 
 /// Negative exponential distribution
 /// with hourly failure rate and time.
@@ -256,7 +254,4 @@ class PeriodicTest : public Expression {
   std::unique_ptr<Flavor> flavor_;  ///< Specialized flavor of calculations.
 };
 
-}  // namespace mef
-}  // namespace scram
-
-#endif  // SCRAM_SRC_EXPRESSION_EXPONENTIAL_H_
+}  // namespace scram::mef
