@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017 Olzhas Rakhimov
+ * Copyright (C) 2017-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,28 +18,29 @@
 /// @file
 /// The MEF facilities to call external functions in expressions.
 
-#ifndef SCRAM_SRC_EXPRESSION_EXTERN_H_
-#define SCRAM_SRC_EXPRESSION_EXTERN_H_
+#pragma once
 
 #include <memory>
 #include <string>
 #include <type_traits>
 #include <vector>
 
+#include <boost/dll/shared_library.hpp>
+#include <boost/exception/errinfo_nested_exception.hpp>
+#include <boost/exception_ptr.hpp>
 #include <boost/filesystem/path.hpp>
-#include <boost/noncopyable.hpp>
+#include <boost/system/system_error.hpp>
 
 #include "src/element.h"
 #include "src/error.h"
 #include "src/expression.h"
 
-namespace scram {
-namespace mef {
+namespace scram::mef {
 
 /// The MEF construct to extend expressions with external libraries.
 /// This class dynamically loads and manages libraries.
 /// It supports only very basic interface for C function lookup with its symbol.
-class ExternLibrary : public Element, public Usage, private boost::noncopyable {
+class ExternLibrary : public Element, public Usage {
  public:
   /// @copydoc Element::Element
   ///
@@ -54,40 +55,26 @@ class ExternLibrary : public Element, public Usage, private boost::noncopyable {
                 const boost::filesystem::path& reference_dir, bool system,
                 bool decorate);
 
-  ~ExternLibrary();  ///< Closes the loaded library.
-
-  /// @tparam F  The C free function pointer type.
+  /// @tparam F  The C free function type.
   ///
   /// @param[in] symbol  The function symbol in the library.
   ///
   /// @returns The function pointer resolved from the symbol.
   ///
   /// @throws UndefinedElement  The symbol is not in the library.
-  ///
-  /// @note The functionality should fail at compile time (UB in C)
-  ///       if the platform doesn't support
-  ///       object pointer to function pointer casts.
   template <typename F>
-  std::enable_if_t<std::is_pointer<F>::value &&
-                       std::is_function<std::remove_pointer_t<F>>::value,
-                   F>
+  std::enable_if_t<std::is_function_v<F>, std::add_pointer_t<F>>
   get(const std::string& symbol) const {
-    return reinterpret_cast<F>(get(symbol.c_str()));
+    try {
+      return lib_handle_.get<F>(symbol);
+    } catch (const boost::system::system_error& err) {
+      SCRAM_THROW(UndefinedElement(err.what()))
+          << boost::errinfo_nested_exception(boost::current_exception());
+    }
   }
 
  private:
-  /// Hides all the cross-platform shared library faculties.
-  /// @todo Remove/refactor after switching to Boost 1.61 on Linux.
-  class Pimpl;
-
-  /// @param[in] symbol  The function symbol in the library.
-  ///
-  /// @returns The function loaded from the library symbol.
-  ///
-  /// @throws UndefinedElement  The symbol is not in the library.
-  void* get(const char* symbol) const;
-
-  Pimpl* pimpl_;  ///< Provides basic implementation for function discovery.
+  boost::dll::shared_library lib_handle_;  ///< Shared Library abstraction.
 };
 
 template <typename R, typename... Args>
@@ -99,8 +86,7 @@ class ExternFunction;  // Forward declaration to specialize abstract base.
 ///
 /// The base acts as a factory for generating expressions with given arguments.
 template <>
-class ExternFunction<void>
-    : public Element, public Usage, private boost::noncopyable {
+class ExternFunction<void> : public Element, public Usage {
  public:
   using Element::Element;
 
@@ -131,7 +117,7 @@ using ExternFunctionBase = ExternFunction<void>;  ///< To help Doxygen.
 /// @pre The source dynamic library is loaded as long as this function lives.
 template <typename R, typename... Args>
 class ExternFunction : public ExternFunctionBase {
-  static_assert(std::is_arithmetic<R>::value, "Numeric type functions only.");
+  static_assert(std::is_arithmetic_v<R>, "Numeric type functions only.");
 
   using Pointer = R (*)(Args...);  ///< The function pointer type.
 
@@ -147,7 +133,7 @@ class ExternFunction : public ExternFunctionBase {
   ExternFunction(std::string name, const std::string& symbol,
                  const ExternLibrary& library)
       : ExternFunctionBase(std::move(name)),
-        fptr_(library.get<Pointer>(symbol)) {}
+        fptr_(library.get<R(Args...)>(symbol)) {}
 
   /// Calls the library function with the given numeric arguments.
   R operator()(Args... args) const noexcept { return fptr_(args...); }
@@ -162,35 +148,36 @@ class ExternFunction : public ExternFunctionBase {
 
 namespace detail {  // Helpers for extern function call with Expression values.
 
+/// Evaluates the argument expressions and marshals the result to function.
 /// Marshaller of expressions to extern function calls.
 ///
 /// @tparam N  The number of arguments.
 ///
+/// @param[in] self  The extern function to be called with the argument values.
+/// @param[in] args  The argument expressions.
+/// @param[in] eval  The evaluator of the expressions.
+/// @param[in] values  The results of expression evaluation.
+///
+/// @returns The result of the function call.
+///
 /// @pre The number of arguments is exactly the same at runtime.
-template <int N>
-struct Marshaller {
-  /// Evaluates the argument expressions and marshals the result to function.
-  template <typename F, typename R, typename... Ts, typename... Args>
-  R operator()(const ExternFunction<R, Args...>& self,
-               const std::vector<Expression*>& args, F&& eval,
-               Ts&&... values) const noexcept {
-    double value = eval(args[N - 1]);
-    return Marshaller<N - 1>()(self, args, std::forward<F>(eval), value,
-                               std::forward<Ts>(values)...);
-  }
-};
+template <int N, typename F, typename R, typename... Ts, typename... Args>
+R Marshal(const ExternFunction<R, Args...>& self,
+          const std::vector<Expression*>& args, F&& eval,
+          Ts&&... values) noexcept {
+  static_assert(N >= 0);
+  assert(args.size() >= N);
 
-/// Specialization to call the extern function with argument values.
-template <>
-struct Marshaller<0> {
-  /// Calls the extern function with the argument values.
-  template <typename F, typename R, typename... Ts, typename... Args>
-  R operator()(const ExternFunction<R, Args...>& self,
-               const std::vector<Expression*>&, F&&, Ts&&... values) const
-      noexcept {
+  if constexpr (N == 0) {
+    assert(args.size() == sizeof...(values) && "Incorrect number of args.");
     return self(std::forward<Ts>(values)...);
+
+  } else {
+    double value = eval(args[N - 1]);
+    return Marshal<N - 1>(self, args, std::forward<F>(eval), value,
+                          std::forward<Ts>(values)...);
   }
-};
+}
 
 }  // namespace detail
 
@@ -218,7 +205,7 @@ class ExternExpression
   /// Computes the extern function with the given evaluator for arguments.
   template <typename F>
   double Compute(F&& eval) noexcept {
-    return detail::Marshaller<sizeof...(Args)>()(
+    return detail::Marshal<sizeof...(Args)>(
         extern_function_, Expression::args(), std::forward<F>(eval));
   }
 
@@ -232,7 +219,4 @@ ExternFunction<R, Args...>::apply(std::vector<Expression*> args) const {
   return std::make_unique<ExternExpression<R, Args...>>(this, std::move(args));
 }
 
-}  // namespace mef
-}  // namespace scram
-
-#endif  // SCRAM_SRC_EXPRESSION_EXTERN_H_
+}  // namespace scram::mef
