@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2017 Olzhas Rakhimov
+ * Copyright (C) 2014-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,26 +19,45 @@
 /// A collection of deviate expressions with random distributions
 /// sampled at run-time.
 
-#ifndef SCRAM_SRC_EXPRESSION_RANDOM_DEVIATE_H_
-#define SCRAM_SRC_EXPRESSION_RANDOM_DEVIATE_H_
+#pragma once
 
 #include <memory>
+#include <random>
 #include <vector>
 
 #include <boost/range/iterator_range.hpp>
 
 #include "src/expression.h"
 
-namespace scram {
-namespace mef {
+namespace scram::mef {
 
 /// Abstract base class for all deviate expressions.
 /// These expressions provide quantification for uncertainty and sensitivity.
+///
+/// @note Only single RNG is embedded for convenience.
+///       All the distributions share this RNG.
+///       This is not suitable for parallelized simulations!!!
+///
+/// @todo Parametrize with RNG (requires mef::Expression interface change).
 class RandomDeviate : public Expression {
  public:
   using Expression::Expression;
 
   bool IsDeviate() noexcept override { return true; }
+
+  /// Sets the seed of the underlying random number generator.
+  ///
+  /// @param[in] seed  The seed for RNGs.
+  ///
+  /// @note This is static! Used by all the deriving deviates.
+  static void seed(unsigned seed) noexcept { rng_.seed(seed); }
+
+ protected:
+  /// @returns RNG to be used by derived classes.
+  std::mt19937& rng() { return rng_; }
+
+ private:
+  static std::mt19937 rng_;  ///< The random number generator.
 };
 
 /// Uniform distribution.
@@ -261,7 +280,4 @@ class Histogram : public RandomDeviate {
   IteratorRange weights_;  ///< Weights of the intervals.
 };
 
-}  // namespace mef
-}  // namespace scram
-
-#endif  // SCRAM_SRC_EXPRESSION_RANDOM_DEVIATE_H_
+}  // namespace scram::mef
