@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2017 Olzhas Rakhimov
+ * Copyright (C) 2014-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,26 +18,22 @@
 /// @file
 /// Fault Tree and Component containers.
 
-#ifndef SCRAM_SRC_FAULT_TREE_H_
-#define SCRAM_SRC_FAULT_TREE_H_
+#pragma once
 
 #include <memory>
 #include <string>
 #include <unordered_set>
 #include <vector>
 
-#include <boost/noncopyable.hpp>
-
 #include "ccf_group.h"
 #include "element.h"
 #include "event.h"
 #include "parameter.h"
 
-namespace scram {
-namespace mef {
+namespace scram::mef {
 
 /// Component is for logical grouping of events, gates, and other components.
-class Component : public Element, public Role, private boost::noncopyable {
+class Component : public Element, public Role {
  public:
   /// Constructs a component assuming
   /// that it exists within some fault tree.
@@ -181,7 +177,4 @@ class FaultTree : public Component {
 
 using FaultTreePtr = std::unique_ptr<FaultTree>;  ///< Unique trees in models.
 
-}  // namespace mef
-}  // namespace scram
-
-#endif  // SCRAM_SRC_FAULT_TREE_H_
+}  // namespace scram::mef
