@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2017 Olzhas Rakhimov
+ * Copyright (C) 2014-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,8 +29,7 @@
 #include "event.h"
 #include "logger.h"
 
-namespace scram {
-namespace core {
+namespace scram::core {
 
 void Print(const ProductContainer& products) {
   if (products.empty()) {
@@ -136,5 +135,4 @@ void FaultTreeAnalysis::Store(const Zbdd& products,
 #endif
 }
 
-}  // namespace core
-}  // namespace scram
+}  // namespace scram::core
