@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2017 Olzhas Rakhimov
+ * Copyright (C) 2014-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,8 +44,7 @@
 #include "ext/find_iterator.h"
 #include "logger.h"
 
-namespace scram {
-namespace mef {
+namespace scram::mef {
 
 namespace {  // Helper function and wrappers for MEF initializations.
 
@@ -54,7 +53,7 @@ namespace {  // Helper function and wrappers for MEF initializations.
 /// @param[in] s  Non-empty, valid role specifier string.
 ///
 /// @returns Role specifier attribute for elements.
-RoleSpecifier GetRole(const xml::string_view& s) {
+RoleSpecifier GetRole(const std::string_view& s) {
   assert(!s.empty());
   assert(s == "public" || s == "private");
   return s == "public" ? RoleSpecifier::kPublic : RoleSpecifier::kPrivate;
@@ -66,7 +65,7 @@ RoleSpecifier GetRole(const xml::string_view& s) {
 /// @param[in] parent_role  The role to be inherited.
 ///
 /// @returns The role for the element under consideration.
-RoleSpecifier GetRole(const xml::string_view& s, RoleSpecifier parent_role) {
+RoleSpecifier GetRole(const std::string_view& s, RoleSpecifier parent_role) {
   return s.empty() ? parent_role : GetRole(s);
 }
 
@@ -81,20 +80,20 @@ RoleSpecifier GetRole(const xml::string_view& s, RoleSpecifier parent_role) {
 /// @throws ValidityError  Invalid attribute setting.
 void AttachLabelAndAttributes(const xml::Element& xml_element,
                               Element* element) {
-  if (boost::optional<xml::Element> label = xml_element.child("label")) {
+  if (std::optional<xml::Element> label = xml_element.child("label")) {
     assert(element->label().empty() && "Resetting element label.");
-    element->label(label->text().to_string());
+    element->label(std::string(label->text()));
   }
 
-  boost::optional<xml::Element> attributes = xml_element.child("attributes");
+  std::optional<xml::Element> attributes = xml_element.child("attributes");
   if (!attributes)
     return;
   for (const xml::Element& attribute : attributes->children()) {
     assert(attribute.name() == "attribute");
     try {
-      element->AddAttribute({attribute.attribute("name").to_string(),
-                             attribute.attribute("value").to_string(),
-                             attribute.attribute("type").to_string()});
+      element->AddAttribute({std::string(attribute.attribute("name")),
+                             std::string(attribute.attribute("value")),
+                             std::string(attribute.attribute("type"))});
     } catch (ValidityError& err) {
       err << boost::errinfo_at_line(attribute.line());
       throw;
@@ -104,20 +103,21 @@ void AttachLabelAndAttributes(const xml::Element& xml_element,
 
 /// Constructs Element of type T from an XML element.
 template <class T>
-std::enable_if_t<std::is_base_of<Element, T>::value, std::unique_ptr<T>>
+std::enable_if_t<std::is_base_of_v<Element, T>, std::unique_ptr<T>>
 ConstructElement(const xml::Element& xml_element) {
-  auto element = std::make_unique<T>(xml_element.attribute("name").to_string());
+  auto element =
+      std::make_unique<T>(std::string(xml_element.attribute("name")));
   AttachLabelAndAttributes(xml_element, element.get());
   return element;
 }
 
 /// Constructs Element of type T with a role from an XML element.
 template <class T>
-std::enable_if_t<std::is_base_of<Role, T>::value, std::unique_ptr<T>>
+std::enable_if_t<std::is_base_of_v<Role, T>, std::unique_ptr<T>>
 ConstructElement(const xml::Element& xml_element, const std::string& base_path,
                  RoleSpecifier base_role) {
   auto element =
-      std::make_unique<T>(xml_element.attribute("name").to_string(), base_path,
+      std::make_unique<T>(std::string(xml_element.attribute("name")), base_path,
                           GetRole(xml_element.attribute("role"), base_role));
   AttachLabelAndAttributes(xml_element, element.get());
   return element;
@@ -131,7 +131,7 @@ ConstructElement(const xml::Element& xml_element, const std::string& base_path,
 auto GetNonAttributeElements(const xml::Element& xml_element) {
   return xml_element.children() |
          boost::adaptors::filtered([](const xml::Element& child) {
-           xml::string_view name = child.name();
+           std::string_view name = child.name();
            return name != "label" && name != "attributes";
          });
 }
@@ -141,7 +141,7 @@ PhasePtr ConstructElement<Phase>(const xml::Element& xml_element) {
   PhasePtr element;
   try {
     element = std::make_unique<Phase>(
-        xml_element.attribute("name").to_string(),
+        std::string(xml_element.attribute("name")),
         *xml_element.attribute<double>("time-fraction"));
   } catch (ValidityError& err) {
     err << boost::errinfo_at_line(xml_element.line());
@@ -281,7 +281,7 @@ HouseEvent* Initializer::Register(const xml::Element& event_node,
   path_house_events_.insert(house_event);
 
   // Only Boolean xml.
-  if (boost::optional<xml::Element> constant = event_node.child("constant")) {
+  if (std::optional<xml::Element> constant = event_node.child("constant")) {
     house_event->state(*constant->attribute<bool>("value"));
   }
   return house_event;
@@ -299,7 +299,7 @@ Parameter* Initializer::Register(const xml::Element& param_node,
   tbd_.emplace_back(parameter, param_node);
 
   // Attach units.
-  xml::string_view unit = param_node.attribute("unit");
+  std::string_view unit = param_node.attribute("unit");
   if (!unit.empty()) {
     int pos = boost::find(kUnitsToString, unit) - std::begin(kUnitsToString);
     assert(pos < kNumUnits && "Unexpected unit kind.");
@@ -313,7 +313,7 @@ CcfGroup* Initializer::Register(const xml::Element& ccf_node,
                                 const std::string& base_path,
                                 RoleSpecifier container_role) {
   auto ptr = [&]() -> CcfGroupPtr {
-    xml::string_view model = ccf_node.attribute("model");
+    std::string_view model = ccf_node.attribute("model");
     if (model == "beta-factor")
       return ConstructElement<BetaFactorModel>(ccf_node, base_path,
                                                container_role);
@@ -348,7 +348,7 @@ Sequence* Initializer::Register(const xml::Element& xml_node,
 /// @}
 
 void Initializer::ProcessInputFile(const std::string& xml_file) {
-  static xml::Validator validator(Env::input_schema());
+  static xml::Validator validator(env::input_schema());
 
   CLOCK(parse_time);
   LOG(DEBUG3) << "Parsing " << xml_file << " ...";
@@ -459,7 +459,7 @@ void Initializer::Define(const xml::Element& param_node, Parameter* parameter) {
 template <>
 void Initializer::Define(const xml::Element& ccf_node, CcfGroup* ccf_group) {
   for (const xml::Element& element : ccf_node.children()) {
-    xml::string_view name = element.name();
+    std::string_view name = element.name();
     if (name == "distribution") {
       ccf_group->AddDistribution(
           GetExpression(*element.child(), ccf_group->base_path()));
@@ -501,7 +501,7 @@ void Initializer::Define(const xml::Element& et_node, EventTree* event_tree) {
 template <>
 void Initializer::Define(const xml::Element& xml_node,
                          InitiatingEvent* initiating_event) {
-  std::string event_tree_name = xml_node.attribute("event-tree").to_string();
+  std::string event_tree_name(xml_node.attribute("event-tree"));
   if (!event_tree_name.empty()) {
     if (auto it = ext::find(model_->event_trees(), event_tree_name)) {
       initiating_event->event_tree(it->get());
@@ -554,10 +554,10 @@ void Initializer::Define(const xml::Element& xml_node,
   substitution->hypothesis(
       GetFormula(xml_node.child("hypothesis")->child().value(), ""));
 
-  if (boost::optional<xml::Element> source = xml_node.child("source")) {
+  if (std::optional<xml::Element> source = xml_node.child("source")) {
     for (const xml::Element& basic_event : source->children()) {
       assert(basic_event.name() == "basic-event");
-      std::string name = basic_event.attribute("name").to_string();
+      std::string name(basic_event.attribute("name"));
       try {
         BasicEvent* event = GetBasicEvent(name, "");
         substitution->Add(event);
@@ -575,7 +575,7 @@ void Initializer::Define(const xml::Element& xml_node,
 
   xml::Element target = xml_node.child("target")->child().value();
   if (target.name() == "basic-event") {
-    std::string name = target.attribute("name").to_string();
+    std::string name(target.attribute("name"));
     try {
       BasicEvent* event = GetBasicEvent(name, "");
       substitution->target(event);
@@ -591,9 +591,9 @@ void Initializer::Define(const xml::Element& xml_node,
 
   try {
     substitution->Validate();
-    xml::string_view type = xml_node.attribute("type");
+    std::string_view type = xml_node.attribute("type");
     if (!type.empty()) {
-      boost::optional<Substitution::Type> deduced_type = substitution->type();
+      std::optional<Substitution::Type> deduced_type = substitution->type();
       int pos = std::distance(kSubstitutionTypeToString,
                               boost::find(kSubstitutionTypeToString, type));
       assert(pos < 3 && "Unexpected substitution type string.");
@@ -616,22 +616,21 @@ void Initializer::ProcessTbdElements() {
       try {
         DefineExternFunction(node);
       } catch (ValidityError& err) {
-        err << boost::errinfo_file_name(root.filename().to_string());
+        err << boost::errinfo_file_name(root.filename());
         throw;
       }
     }
   }
 
-  for (const auto& tbd_element : tbd_) {
+  for (const auto & [ tbd_element, xml_element ] : tbd_) {
     try {
-      boost::apply_visitor(
-          [this, &tbd_element](auto* tbd_construct) {
-            this->Define(tbd_element.second, tbd_construct);
+      std::visit(
+          [this, &xml_element](auto* tbd_construct) {
+            this->Define(xml_element, tbd_construct);
           },
-          tbd_element.first);
+          tbd_element);
     } catch (ValidityError& err) {
-      err << boost::errinfo_file_name(
-          tbd_element.second.filename().to_string());
+      err << boost::errinfo_file_name(xml_element.filename());
       throw;
     }
   }
@@ -750,15 +749,15 @@ FormulaPtr Initializer::GetFormula(const xml::Element& formula_node,
       return;
     }
 
-    std::string name = element.attribute("name").to_string();
+    std::string name(element.attribute("name"));
     if (name.empty()) {
       formula->AddArgument(GetFormula(element, base_path));
       return;
     }
 
-    xml::string_view element_type = [&element] {
+    std::string_view element_type = [&element] {
       // This is for the case "<event name="id" type="type"/>".
-      xml::string_view type = element.attribute("type");
+      std::string_view type = element.attribute("type");
       return type.empty() ? element.name() : type;
     }();
 
@@ -778,7 +777,7 @@ FormulaPtr Initializer::GetFormula(const xml::Element& formula_node,
       }
     } catch (std::out_of_range&) {
       SCRAM_THROW(ValidityError(
-          "Undefined " + element_type.to_string() + " " + name +
+          "Undefined " + std::string(element_type) + " " + name +
           (base_path.empty() ? "" : " with base path " + base_path)))
           << boost::errinfo_at_line(element.line());
     } catch (DuplicateArgumentError& err) {
@@ -810,11 +809,11 @@ FormulaPtr Initializer::GetFormula(const xml::Element& formula_node,
 void Initializer::DefineBranchTarget(const xml::Element& target_node,
                                      EventTree* event_tree, Branch* branch) {
   if (target_node.name() == "fork") {
-    std::string name = target_node.attribute("functional-event").to_string();
+    std::string name(target_node.attribute("functional-event"));
     if (auto it = ext::find(event_tree->functional_events(), name)) {
       std::vector<Path> paths;
       for (const xml::Element& path_element : target_node.children("path")) {
-        paths.emplace_back(path_element.attribute("state").to_string());
+        paths.emplace_back(std::string(path_element.attribute("state")));
         DefineBranch(path_element.children(), event_tree, &paths.back());
       }
       assert(!paths.empty());
@@ -833,7 +832,7 @@ void Initializer::DefineBranchTarget(const xml::Element& target_node,
           << boost::errinfo_at_line(target_node.line());
     }
   } else if (target_node.name() == "sequence") {
-    std::string name = target_node.attribute("name").to_string();
+    std::string name(target_node.attribute("name"));
     if (auto it = ext::find(model_->sequences(), name)) {
       branch->target(it->get());
       (*it)->usage(true);
@@ -844,7 +843,7 @@ void Initializer::DefineBranchTarget(const xml::Element& target_node,
     }
   } else {
     assert(target_node.name() == "branch");
-    std::string name = target_node.attribute("name").to_string();
+    std::string name(target_node.attribute("name"));
     if (auto it = ext::find(event_tree->branches(), name)) {
       branch->target(it->get());
       (*it)->usage(true);
@@ -874,9 +873,9 @@ void Initializer::DefineBranch(const SinglePassRange& xml_nodes,
 }
 
 Instruction* Initializer::GetInstruction(const xml::Element& xml_element) {
-  xml::string_view node_name = xml_element.name();
+  std::string_view node_name = xml_element.name();
   if (node_name == "rule") {
-    std::string name = xml_element.attribute("name").to_string();
+    std::string name(xml_element.attribute("name"));
     if (auto it = ext::find(model_->rules(), name)) {
       (*it)->usage(true);
       return it->get();
@@ -894,7 +893,7 @@ Instruction* Initializer::GetInstruction(const xml::Element& xml_element) {
   };
 
   if (node_name == "event-tree") {
-    std::string name = xml_element.attribute("name").to_string();
+    std::string name(xml_element.attribute("name"));
     if (auto it = ext::find(model_->event_trees(), name)) {
       (*it)->usage(true);
       links_.push_back(static_cast<Link*>(
@@ -938,7 +937,7 @@ Instruction* Initializer::GetInstruction(const xml::Element& xml_element) {
   }
 
   if (node_name == "set-house-event") {
-    std::string name = xml_element.attribute("name").to_string();
+    std::string name(xml_element.attribute("name"));
     if (!model_->house_events().count(name)) {
       SCRAM_THROW(ValidityError("House event " + name +
                                 " is not defined in the model."))
@@ -989,36 +988,19 @@ struct Initializer::Extractor {
                                 xml::Element::Range::iterator it_end,
                                 const std::string& base_path, Initializer* init,
                                 Ts&&... expressions) {
-    assert(it != it_end && "Not enough arguments in the args container.");
-    return Extractor<T, N - 1>()(std::next(it), it_end, base_path, init,
-                                 std::forward<Ts>(expressions)...,
-                                 init->GetExpression(*it, base_path));
-  }
-};
+    static_assert(N >= 0);
 
-/// Partial specialization for terminal Extractor.
-template <class T>
-struct Initializer::Extractor<T, 0> {
-  /// Constructs the requested expression T
-  /// with all accumulated argument expressions.
-  ///
-  /// @tparam Ts  Expression types.
-  ///
-  /// @param[in] it  The iterator in the argument container.
-  /// @param[in] it_end  The end sentinel iterator of the argument container.
-  /// @param[in] expressions  All argument expressions for constructing T.
-  ///
-  /// @returns The constructed expression.
-  ///
-  /// @pre All the elements in the argument container has been processed.
-  template <class... Ts>
-  std::unique_ptr<T> operator()(xml::Element::Range::iterator it,
-                                xml::Element::Range::iterator it_end,
-                                const std::string& /*base_path*/,
-                                Initializer* /*init*/, Ts&&... expressions) {
-    static_assert(sizeof...(Ts), "Unintended use case.");
-    assert(it == it_end && "Too many arguments in the args container.");
-    return std::make_unique<T>(std::forward<Ts>(expressions)...);
+    if constexpr (N == 0) {
+      static_assert(sizeof...(Ts), "Unintended use case.");
+      assert(it == it_end && "Too many arguments in the args container.");
+      return std::make_unique<T>(std::forward<Ts>(expressions)...);
+
+    } else {
+      assert(it != it_end && "Not enough arguments in the args container.");
+      return Extractor<T, N - 1>()(std::next(it), it_end, base_path, init,
+                                   std::forward<Ts>(expressions)...,
+                                   init->GetExpression(*it, base_path));
+    }
   }
 };
 
@@ -1047,39 +1029,23 @@ namespace {  // Expression extraction helper functions.
 
 /// @returns The number of constructor arguments for Expression types.
 /// @{
-template <class T, class... As>
-constexpr int count_args(std::true_type) {
-  return sizeof...(As);
-}
-
-template <class T, class... As>
-constexpr int count_args();
-
 template <class T, class A, class... As>
-constexpr int count_args(std::false_type) {
-  return count_args<T, A, A, As...>();
-}
-
-template <class T, class... As>
 constexpr int count_args() {
-  return count_args<T, As...>(std::is_constructible<T, As...>());
+  if constexpr (std::is_constructible_v<T, A, As...>) {
+    return 1 + sizeof...(As);
+  } else {
+    return count_args<T, A, A, As...>();
+  }
 }
 
 template <class T>
-constexpr int num_args(std::false_type) {
-  return count_args<T, Expression*>();
-}
-
-template <class T>
-constexpr int num_args(std::true_type) {
-  return -1;
-}
-
-template <class T>
-constexpr std::enable_if_t<std::is_base_of<Expression, T>::value, int>
-num_args() {
-  static_assert(!std::is_default_constructible<T>::value, "No zero args.");
-  return num_args<T>(std::is_constructible<T, std::vector<Expression*>>());
+constexpr std::enable_if_t<std::is_base_of_v<Expression, T>, int> num_args() {
+  static_assert(!std::is_default_constructible_v<T>, "No zero args.");
+  if constexpr (std::is_constructible_v<T, std::vector<Expression*>>) {
+    return -1;
+  } else {
+    return count_args<T, Expression*>();
+  }
 }
 /// @}
 
@@ -1217,7 +1183,7 @@ const Initializer::ExtractorMap Initializer::kExpressionExtractors_ = {
 
 Expression* Initializer::GetExpression(const xml::Element& expr_element,
                                        const std::string& base_path) {
-  xml::string_view expr_type = expr_element.name();
+  std::string_view expr_type = expr_element.name();
   auto register_expression = [this](std::unique_ptr<Expression> expression) {
     auto* ret_ptr = expression.get();
     model_->Add(std::move(expression));
@@ -1240,17 +1206,17 @@ Expression* Initializer::GetExpression(const xml::Element& expr_element,
 
   if (expr_type == "test-initiating-event") {
     return register_expression(std::make_unique<TestInitiatingEvent>(
-        expr_element.attribute("name").to_string(), model_->context()));
+        std::string(expr_element.attribute("name")), model_->context()));
   }
   if (expr_type == "test-functional-event") {
     return register_expression(std::make_unique<TestFunctionalEvent>(
-        expr_element.attribute("name").to_string(),
-        expr_element.attribute("state").to_string(), model_->context()));
+        std::string(expr_element.attribute("name")),
+        std::string(expr_element.attribute("state")), model_->context()));
   }
 
   if (expr_type == "extern-function") {
     const ExternFunction<void>* extern_function = [this, &expr_element] {
-      std::string name = expr_element.attribute("name").to_string();
+      std::string name(expr_element.attribute("name"));
       auto it = model_->extern_functions().find(name);
       if (it == model_->extern_functions().end()) {
         SCRAM_THROW(ValidityError("Undefined extern function: " + name))
@@ -1277,7 +1243,7 @@ Expression* Initializer::GetExpression(const xml::Element& expr_element,
 
   try {
     Expression* expression = register_expression(kExpressionExtractors_.at(
-        expr_type.to_string())(expr_element.children(), base_path, this));
+        expr_type)(expr_element.children(), base_path, this));
     // Register for late validation after ensuring no cycles.
     expressions_.emplace_back(expression, expr_element);
     return expression;
@@ -1287,11 +1253,11 @@ Expression* Initializer::GetExpression(const xml::Element& expr_element,
   }
 }
 
-Expression* Initializer::GetParameter(const xml::string_view& expr_type,
+Expression* Initializer::GetParameter(const std::string_view& expr_type,
                                       const xml::Element& expr_element,
                                       const std::string& base_path) {
   auto check_units = [&expr_element](const auto& parameter) {
-    xml::string_view unit = expr_element.attribute("unit");
+    std::string_view unit = expr_element.attribute("unit");
     const char* param_unit = scram::mef::kUnitsToString[parameter.unit()];
     if (!unit.empty() && unit != param_unit) {
       std::stringstream msg;
@@ -1303,7 +1269,7 @@ Expression* Initializer::GetParameter(const xml::string_view& expr_type,
   };
 
   if (expr_type == "parameter") {
-    std::string name = expr_element.attribute("name").to_string();
+    std::string name(expr_element.attribute("name"));
     try {
       Parameter* param = GetParameter(name, base_path);
       param->usage(true);
@@ -1327,7 +1293,7 @@ void Initializer::ProcessCcfMembers(const xml::Element& members_node,
   for (const xml::Element& event_node : members_node.children()) {
     assert("basic-event" == event_node.name());
     auto basic_event =
-        std::make_unique<BasicEvent>(event_node.attribute("name").to_string(),
+        std::make_unique<BasicEvent>(std::string(event_node.attribute("name")),
                                      ccf_group->base_path(), ccf_group->role());
     try {
       ccf_group->AddMember(basic_event.get());
@@ -1435,14 +1401,14 @@ Formula::EventArg Initializer::GetEvent(const std::string& entity_reference,
 void Initializer::DefineExternLibraries(const xml::Element& xml_node,
                                         const std::string& xml_file) {
   auto optional_bool = [&xml_node](const char* tag) {
-    boost::optional<bool> attribute = xml_node.attribute<bool>(tag);
+    std::optional<bool> attribute = xml_node.attribute<bool>(tag);
     return attribute ? *attribute : false;
   };
   auto library = [&xml_file, &xml_node, &optional_bool] {
     try {
       return std::make_unique<ExternLibrary>(
-          xml_node.attribute("name").to_string(),
-          xml_node.attribute("path").to_string(),
+          std::string(xml_node.attribute("name")),
+          std::string(xml_node.attribute("path")),
           boost::filesystem::path(xml_file).parent_path(),
           optional_bool("system"), optional_bool("decorate"));
     } catch (DLError& err) {
@@ -1481,7 +1447,7 @@ template <class SinglePassRange>
 int Encode(const SinglePassRange& args) noexcept {
   assert(!args.empty());
   auto to_digit = [](const xml::Element& node) -> int {
-    xml::string_view name = node.name();
+    std::string_view name = node.name();
     return static_cast<int>([&name] {
       if (name == "int")
         return ExternParamType::kInt;
@@ -1501,22 +1467,19 @@ int Encode(const SinglePassRange& args) noexcept {
 }
 
 /// Encodes function parameter types at compile-time.
-/// @{
 template <typename T, typename... Ts>
 constexpr int Encode(int base_power = 1) noexcept {
-  return Encode<T>(base_power) + Encode<Ts...>(base_power * kExternTypeBase);
-}
+  if constexpr (sizeof...(Ts)) {
+    return Encode<T>(base_power) + Encode<Ts...>(base_power * kExternTypeBase);
 
-template <>
-constexpr int Encode<int>(int base_power) noexcept {
-  return base_power * static_cast<int>(ExternParamType::kInt);
-}
+  } else if constexpr (std::is_same_v<T, int>) {
+    return base_power * static_cast<int>(ExternParamType::kInt);
 
-template <>
-constexpr int Encode<double>(int base_power) noexcept {
-  return base_power * static_cast<int>(ExternParamType::kDouble);
+  } else {
+    static_assert(std::is_same_v<T, double>);
+    return base_power * static_cast<int>(ExternParamType::kDouble);
+  }
 }
-/// @}
 
 using ExternFunctionExtractor = ExternFunctionPtr (*)(std::string,
                                                       const std::string&,
@@ -1524,37 +1487,31 @@ using ExternFunctionExtractor = ExternFunctionPtr (*)(std::string,
 using ExternFunctionExtractorMap =
     std::unordered_map<int, ExternFunctionExtractor>;
 
+/// Generates all extractors for extern functions.
+///
 /// @tparam N  The number of parameters.
-template <int N>
-struct ExternFunctionGenerator;
+/// @tparam Ts  The return and parameter types of the extern function.
+///
+/// @param[in,out] function_map  The destination container for extractor.
+template <int N, typename... Ts>
+void GenerateExternFunctionExtractor(ExternFunctionExtractorMap* function_map) {
+  static_assert(N >= 0);
+  static_assert(sizeof...(Ts));
 
-template <>
-struct ExternFunctionGenerator<0> {
-  template <typename... Ts>
-  static void Generate(ExternFunctionExtractorMap* function_map) noexcept {
-    ///< @todo GCC 4.9, 5.4 segfaults on move for lambda arguments.
-    struct Extractor {  // Use instead of lambda!
-      static ExternFunctionPtr Extract(std::string name,
-                                       const std::string& symbol,
-                                       const ExternLibrary& library) {
-        return std::make_unique<ExternFunction<Ts...>>(std::move(name), symbol,
-                                                       library);
-      }
-    };
-    function_map->emplace(Encode<Ts...>(), &Extractor::Extract);
+  if constexpr (N == 0) {
+    function_map->emplace(
+        Encode<Ts...>(),
+        [](std::string name, const std::string& symbol,
+           const ExternLibrary& library) -> ExternFunctionPtr {
+          return std::make_unique<ExternFunction<Ts...>>(std::move(name),
+                                                         symbol, library);
+        });
+  } else {
+    GenerateExternFunctionExtractor<0, Ts...>(function_map);
+    GenerateExternFunctionExtractor<N - 1, Ts..., int>(function_map);
+    GenerateExternFunctionExtractor<N - 1, Ts..., double>(function_map);
   }
-};
-
-template <int N>
-struct ExternFunctionGenerator {
-  template <typename... Ts>
-  static void Generate(ExternFunctionExtractorMap* function_map) noexcept {
-    ExternFunctionGenerator<0>::template Generate<Ts...>(function_map);
-    ExternFunctionGenerator<N - 1>::template Generate<Ts..., int>(function_map);
-    ExternFunctionGenerator<N - 1>::template Generate<Ts..., double>(
-        function_map);
-  }
-};
+}
 
 }  // namespace
 
@@ -1562,14 +1519,14 @@ void Initializer::DefineExternFunction(const xml::Element& xml_element) {
   static const ExternFunctionExtractorMap function_extractors = [] {
     ExternFunctionExtractorMap function_map;
     function_map.reserve(kNumInterfaces);
-    ExternFunctionGenerator<kMaxNumParam>::Generate<int>(&function_map);
-    ExternFunctionGenerator<kMaxNumParam>::Generate<double>(&function_map);
+    GenerateExternFunctionExtractor<kMaxNumParam, int>(&function_map);
+    GenerateExternFunctionExtractor<kMaxNumParam, double>(&function_map);
     assert(function_map.size() == kNumInterfaces);
     return function_map;
   }();
 
   const ExternLibrary& library = [this, &xml_element]() -> decltype(auto) {
-    std::string lib_name = xml_element.attribute("library").to_string();
+    std::string lib_name(xml_element.attribute("library"));
     auto it = model_->libraries().find(lib_name);
     if (it == model_->libraries().end())
       SCRAM_THROW(ValidityError("Undefined extern library: " + lib_name))
@@ -1593,8 +1550,8 @@ void Initializer::DefineExternFunction(const xml::Element& xml_element) {
     int encoding = Encode(args);
     try {
       return function_extractors.at(encoding)(
-          xml_element.attribute("name").to_string(),
-          xml_element.attribute("symbol").to_string(), library);
+          std::string(xml_element.attribute("name")),
+          std::string(xml_element.attribute("symbol")), library);
     } catch (ValidityError& err) {
       err << boost::errinfo_at_line(xml_element.line());
       throw;
@@ -1675,7 +1632,7 @@ void Initializer::CheckFunctionalEventOrder(const Branch& branch) {
     void operator()(Sequence*) const {}
 
     void operator()(NamedBranch* named_branch) const {
-      boost::apply_visitor(*this, named_branch->target());
+      std::visit(*this, named_branch->target());
     }
 
     void operator()(Fork* fork) const {
@@ -1702,14 +1659,13 @@ void Initializer::CheckFunctionalEventOrder(const Branch& branch) {
     void operator()(Fork* fork) const {
       for (const Path& fork_path : fork->paths()) {
         initializer->CheckFunctionalEventOrder(fork_path);
-        boost::apply_visitor(CheckOrder{fork->functional_event()},
-                             fork_path.target());
+        std::visit(CheckOrder{fork->functional_event()}, fork_path.target());
       }
     }
     Initializer* initializer;
   };
 
-  boost::apply_visitor(OrderValidator{this}, branch.target());
+  std::visit(OrderValidator{this}, branch.target());
 }
 
 void Initializer::EnsureLinksOnlyInSequences(const Branch& branch) {
@@ -1727,7 +1683,7 @@ void Initializer::EnsureLinksOnlyInSequences(const Branch& branch) {
     void operator()(const Branch* arg_branch) {
       for (const Instruction* instruction : arg_branch->instructions())
         instruction->Accept(&validator);
-      boost::apply_visitor(*this, arg_branch->target());
+      std::visit(*this, arg_branch->target());
     }
 
     void operator()(Fork* fork) {
@@ -1782,7 +1738,7 @@ void Initializer::EnsureHomogeneousEventTree(const Branch& branch) {
     }
     void operator()(const Branch* arg_branch) {
       CheckInstructions(arg_branch->instructions());
-      boost::apply_visitor(*this, arg_branch->target());
+      std::visit(*this, arg_branch->target());
     }
     void operator()(const Fork* fork) {
       for (const Path& fork_path : fork->paths())
@@ -1801,7 +1757,7 @@ void Initializer::EnsureNoSubstitutionConflicts() {
                          return !substitution->declarative();
                        });
   for (const SubstitutionPtr& origin : substitutions) {
-    const auto* target_ptr = boost::get<BasicEvent*>(&origin->target());
+    const auto* target_ptr = std::get_if<BasicEvent*>(&origin->target());
     for (const SubstitutionPtr& substitution : substitutions) {
       if (target_ptr && boost::count(substitution->source(), *target_ptr))
         SCRAM_THROW(ValidityError(
@@ -1812,7 +1768,7 @@ void Initializer::EnsureNoSubstitutionConflicts() {
       auto in_hypothesis = [&substitution](const BasicEvent* source) {
         return ext::any_of(substitution->hypothesis().event_args(),
                            [source](const Formula::EventArg& arg) {
-                             return boost::get<BasicEvent*>(arg) == source;
+                             return std::get<BasicEvent*>(arg) == source;
                            });
       };
       if (target_ptr && in_hypothesis(*target_ptr))
@@ -1837,11 +1793,11 @@ void Initializer::EnsureNoCcfSubstitutions() {
   auto is_ccf = [](const Substitution& substitution) {
     if (ext::any_of(substitution.hypothesis().event_args(),
                     [](const Formula::EventArg& arg) {
-                      return boost::get<BasicEvent*>(arg)->HasCcf();
+                      return std::get<BasicEvent*>(arg)->HasCcf();
                     }))
       return true;
 
-    const auto* target_ptr = boost::get<BasicEvent*>(&substitution.target());
+    const auto* target_ptr = std::get_if<BasicEvent*>(&substitution.target());
     if (target_ptr && (*target_ptr)->HasCcf())
       return true;
 
@@ -1881,7 +1837,7 @@ void Initializer::ValidateExpressions() {
     try {
       expression.first->Validate();
     } catch (ValidityError& err) {
-      err << boost::errinfo_file_name(expression.second.filename().to_string())
+      err << boost::errinfo_file_name(expression.second.filename())
           << boost::errinfo_at_line(expression.second.line());
       throw;
     }
@@ -1917,5 +1873,4 @@ void Initializer::SetupForAnalysis() {
   }
 }
 
-}  // namespace mef
-}  // namespace scram
+}  // namespace scram::mef
