@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2017 Olzhas Rakhimov
+ * Copyright (C) 2014-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,8 +26,7 @@
 /// The timing facilities are inspired by
 /// the talk of Bryce Adelstein "Benchmarking C++ Code" at CppCon 2015.
 
-#ifndef SCRAM_SRC_LOGGER_H_
-#define SCRAM_SRC_LOGGER_H_
+#pragma once
 
 #include <cstdint>
 
@@ -150,5 +149,3 @@ class Timer {
 };
 
 }  // namespace scram
-
-#endif  // SCRAM_SRC_LOGGER_H_
