@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2017 Olzhas Rakhimov
+ * Copyright (C) 2014-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,8 +23,7 @@
 /// That is, negations must be pushed down to leaves, basic events.
 /// The fault tree should not contain constants or house events.
 
-#ifndef SCRAM_SRC_MOCUS_H_
-#define SCRAM_SRC_MOCUS_H_
+#pragma once
 
 #include <unordered_map>
 #include <vector>
@@ -35,8 +34,7 @@
 #include "settings.h"
 #include "zbdd.h"
 
-namespace scram {
-namespace core {
+namespace scram::core {
 
 /// This class analyzes normalized, preprocessed, and indexed fault trees
 /// to generate minimal cut sets with the MOCUS algorithm.
@@ -79,7 +77,4 @@ class Mocus : private boost::noncopyable {
   std::unique_ptr<Zbdd> zbdd_;  ///< ZBDD as a result of analysis.
 };
 
-}  // namespace core
-}  // namespace scram
-
-#endif  // SCRAM_SRC_MOCUS_H_
+}  // namespace scram::core
