@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2017 Olzhas Rakhimov
+ * Copyright (C) 2014-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,15 +18,12 @@
 /// @file
 /// Representation for a model container for risk analysis.
 
-#ifndef SCRAM_SRC_MODEL_H_
-#define SCRAM_SRC_MODEL_H_
+#pragma once
 
 #include <memory>
 #include <string>
 #include <vector>
 
-#include <boost/noncopyable.hpp>
-
 #include "alignment.h"
 #include "ccf_group.h"
 #include "element.h"
@@ -40,11 +37,10 @@
 #include "parameter.h"
 #include "substitution.h"
 
-namespace scram {
-namespace mef {
+namespace scram::mef {
 
 /// This class represents a risk analysis model.
-class Model : public Element, private boost::noncopyable {
+class Model : public Element {
  public:
   /// Only Model is allowed to have an optional name,
   /// while all other Elements require names.
@@ -191,7 +187,4 @@ class Model : public Element, private boost::noncopyable {
   Context context_;  ///< The context to be used by test-event expressions.
 };
 
-}  // namespace mef
-}  // namespace scram
-
-#endif  // SCRAM_SRC_MODEL_H_
+}  // namespace scram::mef
