@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2017 Olzhas Rakhimov
+ * Copyright (C) 2014-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,7 @@
 /// A collection of PDAG transformation/preprocessing algorithms
 /// that simplify fault trees for analysis.
 
-#ifndef SCRAM_SRC_PREPROCESSOR_H_
-#define SCRAM_SRC_PREPROCESSOR_H_
+#pragma once
 
 #include <memory>
 #include <set>
@@ -33,14 +32,10 @@
 
 #include "pdag.h"
 
-namespace scram {
-namespace core {
+namespace scram::core {
 
 namespace pdag {
 
-/// The terminal case for graph transformations.
-inline void Transform(Pdag* /*graph*/) {}
-
 /// Applies graph transformations consecutively.
 ///
 /// @param[in,out] graph  The graph to be transformed.
@@ -50,8 +45,11 @@ template <typename T, typename... Ts>
 void Transform(Pdag* graph, T&& unary_op, Ts&&... unary_ops) noexcept {
   if (graph->IsTrivial())
     return;
+
   unary_op(graph);
-  Transform(graph, std::forward<Ts>(unary_ops)...);
+
+  if constexpr (sizeof...(unary_ops))
+    Transform(graph, std::forward<Ts>(unary_ops)...);
 }
 
 /// Determines the order of traversal for gate arguments.
@@ -1065,7 +1063,4 @@ class CustomPreprocessor<Mocus> : public CustomPreprocessor<Zbdd> {
   void InvertOrder() noexcept;
 };
 
-}  // namespace core
-}  // namespace scram
-
-#endif  // SCRAM_SRC_PREPROCESSOR_H_
+}  // namespace scram::core
