@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2017 Olzhas Rakhimov
+ * Copyright (C) 2014-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
 /// @file
 /// Reporter of results.
 
-#ifndef SCRAM_SRC_REPORTER_H_
-#define SCRAM_SRC_REPORTER_H_
+#pragma once
 
 #include <cstdio>
 
@@ -194,5 +193,3 @@ class Reporter {
 };
 
 }  // namespace scram
-
-#endif  // SCRAM_SRC_REPORTER_H_
