@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2017 Olzhas Rakhimov
+ * Copyright (C) 2014-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,11 +19,9 @@
 /// Set of functions with version information
 /// of the core and dependencies.
 
-#ifndef SCRAM_SRC_VERSION_H_
-#define SCRAM_SRC_VERSION_H_
+#pragma once
 
-namespace scram {
-namespace version {
+namespace scram::version {
 
 /// @returns Git generated tag recent version.
 const char* describe();
@@ -40,7 +38,4 @@ const char* boost();
 /// @returns The version of the XML C library.
 const char* libxml();
 
-}  // namespace version
-}  // namespace scram
-
-#endif  // SCRAM_SRC_VERSION_H_
+}  // namespace scram::version
