@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2017 Olzhas Rakhimov
+ * Copyright (C) 2014-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,13 +15,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <gtest/gtest.h>
-
 #include "risk_analysis_tests.h"
 
-namespace scram {
-namespace core {
-namespace test {
+namespace scram::core::test {
 
 // Benchmark Tests for the ThreeMotor fault tree from OpenFTA.
 TEST_P(RiskAnalysisTest, ThreeMotor) {
@@ -89,11 +85,10 @@ TEST_F(RiskAnalysisTest, ThreeMotorEventTree) {
   const auto& results = sequences();
   ASSERT_EQ(8, results.size());
   for (const auto& result : expected) {
-    ASSERT_TRUE(results.count(result.first)) << result.first;
-    EXPECT_NEAR(result.second, results.at(result.first), 1e-5) << result.first;
+    INFO("seq: " + result.first);
+    ASSERT_TRUE(results.count(result.first));
+    EXPECT_NEAR(result.second, results.at(result.first), 1e-5);
   }
 }
 
-}  // namespace test
-}  // namespace core
-}  // namespace scram
+}  // namespace scram::core::test
