@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2017 Olzhas Rakhimov
+ * Copyright (C) 2014-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,32 +15,28 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SCRAM_TESTS_PERFORMANCE_TESTS_H_
-#define SCRAM_TESTS_PERFORMANCE_TESTS_H_
+#pragma once
 
 #include <string>
 #include <vector>
 
-#include <gtest/gtest.h>
+#include <catch.hpp>
 
 #include "fault_tree_analysis.h"
 #include "initializer.h"
 #include "probability_analysis.h"
 #include "risk_analysis.h"
 
-namespace scram {
-namespace core {
-namespace test {
+namespace scram::core::test {
 
-class PerformanceTest : public ::testing::Test {
- protected:
-  void SetUp() override {
+class PerformanceTest {
+ public:
+  PerformanceTest() {
     settings.algorithm("mocus");
     delta = 0.10;  // % variation of values.
   }
 
-  void TearDown() override {}
-
+ protected:
   // Convenient function to manage analysis of one model in input files.
   void Analyze(const std::vector<std::string>& input_files) {
     {
@@ -82,8 +78,4 @@ class PerformanceTest : public ::testing::Test {
   double delta;  // The range indicator for values.
 };
 
-}  // namespace test
-}  // namespace core
-}  // namespace scram
-
-#endif  // SCRAM_TESTS_PERFORMANCE_TESTS_H_
+}  // namespace scram::core::test
