@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2017 Olzhas Rakhimov
+ * Copyright (C) 2014-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,21 +27,21 @@
 #include "reporter.h"
 #include "xml.h"
 
-namespace scram {
-namespace core {
-namespace test {
+namespace scram::core::test {
+
+const char* scram::core::test::RiskAnalysisTest::parameter_ = nullptr;
 
 const std::set<std::set<std::string>> RiskAnalysisTest::kUnity = {
     std::set<std::string>{}};
 
-void RiskAnalysisTest::SetUp() {
+RiskAnalysisTest::RiskAnalysisTest() {
   if (HasParam()) {
-    std::string param = GetParam();
+    std::string_view param = GetParam();
     if (param == "pi") {
       settings.algorithm("bdd");
       settings.prime_implicants(true);
     } else {
-      settings.algorithm(GetParam());
+      settings.algorithm(param);
     }
   }
 }
@@ -55,15 +55,15 @@ void RiskAnalysisTest::ProcessInputFiles(
 }
 
 void RiskAnalysisTest::CheckReport(const std::vector<std::string>& tree_input) {
-  static xml::Validator validator(Env::report_schema());
+  static xml::Validator validator(env::report_schema());
 
-  ASSERT_NO_THROW(ProcessInputFiles(tree_input));
-  ASSERT_NO_THROW(analysis->Analyze());
+  REQUIRE_NOTHROW(ProcessInputFiles(tree_input));
+  REQUIRE_NOTHROW(analysis->Analyze());
   fs::path temp_file = utility::GenerateFilePath();
-  ASSERT_NO_THROW(Reporter().Report(*analysis, temp_file.string()))
-      << tree_input.front() << " => " << temp_file;
-  ASSERT_NO_THROW(xml::Document(temp_file.string(), &validator))
-      << tree_input.front() << " => " << temp_file;
+  INFO("input: " + tree_input.front());
+  INFO("output: " + temp_file.string());
+  REQUIRE_NOTHROW(Reporter().Report(*analysis, temp_file.string()));
+  REQUIRE_NOTHROW(xml::Document(temp_file.string(), &validator));
   fs::remove(temp_file);
 }
 
@@ -126,91 +126,91 @@ std::set<std::string> RiskAnalysisTest::Convert(const Product& product) {
 
 TEST_F(RiskAnalysisTest, ProcessInput) {
   std::string tree_input = "tests/input/fta/correct_tree_input.xml";
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  EXPECT_EQ(3, gates().size());
-  EXPECT_EQ(1, gates().count("TrainOne"));
-  EXPECT_EQ(1, gates().count("TrainTwo"));
-  EXPECT_EQ(1, gates().count("TopEvent"));
-  EXPECT_EQ(4, basic_events().size());
-  EXPECT_EQ(1, basic_events().count("PumpOne"));
-  EXPECT_EQ(1, basic_events().count("PumpTwo"));
-  EXPECT_EQ(1, basic_events().count("ValveOne"));
-  EXPECT_EQ(1, basic_events().count("ValveTwo"));
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  CHECK(gates().size() == 3);
+  CHECK(gates().count("TrainOne") == 1);
+  CHECK(gates().count("TrainTwo") == 1);
+  CHECK(gates().count("TopEvent") == 1);
+  CHECK(basic_events().size() == 4);
+  CHECK(basic_events().count("PumpOne") == 1);
+  CHECK(basic_events().count("PumpTwo") == 1);
+  CHECK(basic_events().count("ValveOne") == 1);
+  CHECK(basic_events().count("ValveTwo") == 1);
 
-  ASSERT_TRUE(gates().count("TopEvent"));
+  REQUIRE(gates().count("TopEvent"));
   mef::Gate* top = gates().find("TopEvent")->get();
-  EXPECT_EQ("TopEvent", top->id());
-  ASSERT_NO_THROW(top->formula().type());
-  EXPECT_EQ(mef::kAnd, top->formula().type());
-  EXPECT_EQ(2, top->formula().event_args().size());
+  CHECK(top->id() == "TopEvent");
+  REQUIRE_NOTHROW(top->formula().type());
+  CHECK(top->formula().type() == mef::kAnd);
+  CHECK(top->formula().event_args().size() == 2);
 
-  ASSERT_TRUE(gates().count("TrainOne"));
+  REQUIRE(gates().count("TrainOne"));
   mef::Gate* inter = gates().find("TrainOne")->get();
-  EXPECT_EQ("TrainOne", inter->id());
-  ASSERT_NO_THROW(inter->formula().type());
-  EXPECT_EQ(mef::kOr, inter->formula().type());
-  EXPECT_EQ(2, inter->formula().event_args().size());
+  CHECK(inter->id() == "TrainOne");
+  REQUIRE_NOTHROW(inter->formula().type());
+  CHECK(inter->formula().type() == mef::kOr);
+  CHECK(inter->formula().event_args().size() == 2);
 
-  ASSERT_TRUE(basic_events().count("ValveOne"));
+  REQUIRE(basic_events().count("ValveOne"));
   mef::BasicEvent* primary = basic_events().find("ValveOne")->get();
-  EXPECT_EQ("ValveOne", primary->id());
+  CHECK(primary->id() == "ValveOne");
 }
 
 // Test Probability Assignment
 TEST_F(RiskAnalysisTest, PopulateProbabilities) {
   // Input with probabilities
   std::string tree_input = "tests/input/fta/correct_tree_input_with_probs.xml";
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  ASSERT_EQ(4, basic_events().size());
-  ASSERT_EQ(1, basic_events().count("PumpOne"));
-  ASSERT_EQ(1, basic_events().count("PumpTwo"));
-  ASSERT_EQ(1, basic_events().count("ValveOne"));
-  ASSERT_EQ(1, basic_events().count("ValveTwo"));
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  REQUIRE(basic_events().size() == 4);
+  REQUIRE(basic_events().count("PumpOne") == 1);
+  REQUIRE(basic_events().count("PumpTwo") == 1);
+  REQUIRE(basic_events().count("ValveOne") == 1);
+  REQUIRE(basic_events().count("ValveTwo") == 1);
 
   mef::BasicEvent* p1 = basic_events().find("PumpOne")->get();
   mef::BasicEvent* p2 = basic_events().find("PumpTwo")->get();
   mef::BasicEvent* v1 = basic_events().find("ValveOne")->get();
   mef::BasicEvent* v2 = basic_events().find("ValveTwo")->get();
 
-  ASSERT_NO_THROW(p1->p());
-  ASSERT_NO_THROW(p2->p());
-  ASSERT_NO_THROW(v1->p());
-  ASSERT_NO_THROW(v2->p());
-  EXPECT_EQ(0.6, p1->p());
-  EXPECT_EQ(0.7, p2->p());
-  EXPECT_EQ(0.4, v1->p());
-  EXPECT_EQ(0.5, v2->p());
+  REQUIRE_NOTHROW(p1->p());
+  REQUIRE_NOTHROW(p2->p());
+  REQUIRE_NOTHROW(v1->p());
+  REQUIRE_NOTHROW(v2->p());
+  CHECK(p1->p() == 0.6);
+  CHECK(p2->p() == 0.7);
+  CHECK(v1->p() == 0.4);
+  CHECK(v2->p() == 0.5);
 }
 
 // Test Analysis of Two train system.
 TEST_P(RiskAnalysisTest, AnalyzeDefault) {
   std::string tree_input = "tests/input/fta/correct_tree_input.xml";
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  ASSERT_NO_THROW(analysis->Analyze());
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  REQUIRE_NOTHROW(analysis->Analyze());
   std::set<std::set<std::string>> mcs = {{"PumpOne", "PumpTwo"},
                                          {"PumpOne", "ValveTwo"},
                                          {"PumpTwo", "ValveOne"},
                                          {"ValveOne", "ValveTwo"}};
-  EXPECT_EQ(mcs, products());
+  CHECK(products() == mcs);
   PrintProducts();  // Quick visual verification.
 }
 
 TEST_P(RiskAnalysisTest, AnalyzeNonCoherentDefault) {
   std::string tree_input = "tests/input/fta/correct_non_coherent.xml";
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  ASSERT_NO_THROW(analysis->Analyze());
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  REQUIRE_NOTHROW(analysis->Analyze());
   if (settings.prime_implicants()) {
     std::set<std::set<std::string>> pi = {{"not PumpOne", "ValveOne"},
                                           {"PumpOne", "PumpTwo"},
                                           {"PumpOne", "ValveTwo"},
                                           {"PumpTwo", "ValveOne"},
                                           {"ValveOne", "ValveTwo"}};
-    EXPECT_EQ(5, products().size());
-    EXPECT_EQ(pi, products());
+    CHECK(products().size() == 5);
+    CHECK(products() == pi);
   } else {
     std::set<std::set<std::string>> mcs = {
         {"PumpOne", "PumpTwo"}, {"PumpOne", "ValveTwo"}, {"ValveOne"}};
-    EXPECT_EQ(mcs, products());
+    CHECK(products() == mcs);
   }
 }
 
@@ -222,19 +222,19 @@ TEST_P(RiskAnalysisTest, AnalyzeWithProbability) {
   std::set<std::string> mcs_4 = {"ValveOne", "ValveTwo"};
   std::set<std::set<std::string>> mcs = {mcs_1, mcs_2, mcs_3, mcs_4};
   settings.probability_analysis(true);
-  ASSERT_NO_THROW(ProcessInputFiles({with_prob}));
-  ASSERT_NO_THROW(analysis->Analyze());
+  REQUIRE_NOTHROW(ProcessInputFiles({with_prob}));
+  REQUIRE_NOTHROW(analysis->Analyze());
 
-  EXPECT_EQ(mcs, products());
+  CHECK(products() == mcs);
   if (settings.approximation() == Approximation::kRareEvent) {
-    EXPECT_DOUBLE_EQ(1, p_total());
+    CHECK(p_total() == Approx(1));
   } else {
-    EXPECT_DOUBLE_EQ(0.646, p_total());
+    CHECK(p_total() == Approx(0.646));
   }
-  EXPECT_DOUBLE_EQ(0.42, product_probability().at(mcs_1));
-  EXPECT_DOUBLE_EQ(0.3, product_probability().at(mcs_2));
-  EXPECT_DOUBLE_EQ(0.28, product_probability().at(mcs_3));
-  EXPECT_DOUBLE_EQ(0.2, product_probability().at(mcs_4));
+  CHECK(product_probability().at(mcs_1) == Approx(0.42));
+  CHECK(product_probability().at(mcs_2) == Approx(0.3));
+  CHECK(product_probability().at(mcs_3) == Approx(0.28));
+  CHECK(product_probability().at(mcs_4) == Approx(0.2));
 }
 
 // Test for exact probability calculation
@@ -242,9 +242,9 @@ TEST_P(RiskAnalysisTest, AnalyzeWithProbability) {
 TEST_P(RiskAnalysisTest, EnforceExactProbability) {
   std::string with_prob = "tests/input/fta/correct_tree_input_with_probs.xml";
   settings.probability_analysis(true).approximation("none");
-  ASSERT_NO_THROW(ProcessInputFiles({with_prob}));
-  ASSERT_NO_THROW(analysis->Analyze());
-  EXPECT_DOUBLE_EQ(0.646, p_total());
+  REQUIRE_NOTHROW(ProcessInputFiles({with_prob}));
+  REQUIRE_NOTHROW(analysis->Analyze());
+  CHECK(p_total() == Approx(0.646));
 }
 
 TEST_P(RiskAnalysisTest, AnalyzeNestedFormula) {
@@ -253,16 +253,16 @@ TEST_P(RiskAnalysisTest, AnalyzeNestedFormula) {
                                          {"PumpOne", "ValveTwo"},
                                          {"PumpTwo", "ValveOne"},
                                          {"ValveOne", "ValveTwo"}};
-  ASSERT_NO_THROW(ProcessInputFiles({nested_input}));
-  ASSERT_NO_THROW(analysis->Analyze());
-  EXPECT_EQ(mcs, products());
+  REQUIRE_NOTHROW(ProcessInputFiles({nested_input}));
+  REQUIRE_NOTHROW(analysis->Analyze());
+  CHECK(products() == mcs);
 }
 
 TEST_F(RiskAnalysisTest, ImportanceDefault) {
   std::string with_prob = "tests/input/fta/correct_tree_input_with_probs.xml";
   settings.importance_analysis(true);
-  ASSERT_NO_THROW(ProcessInputFiles({with_prob}));
-  ASSERT_NO_THROW(analysis->Analyze());
+  REQUIRE_NOTHROW(ProcessInputFiles({with_prob}));
+  REQUIRE_NOTHROW(analysis->Analyze());
   TestImportance({{"PumpOne", {2, 0.51, 0.4737, 0.7895, 1.316, 1.9}},
                   {"PumpTwo", {2, 0.38, 0.4118, 0.8235, 1.176, 1.7}},
                   {"ValveOne", {2, 0.34, 0.2105, 0.5263, 1.316, 1.267}},
@@ -272,9 +272,9 @@ TEST_F(RiskAnalysisTest, ImportanceDefault) {
 TEST_F(RiskAnalysisTest, ImportanceNeg) {
   std::string tree_input = "tests/input/fta/importance_neg_test.xml";
   settings.prime_implicants(true).importance_analysis(true);
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  ASSERT_NO_THROW(analysis->Analyze());
-  EXPECT_NEAR(0.04459, p_total(), 1e-3);
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  REQUIRE_NOTHROW(analysis->Analyze());
+  CHECK(p_total() == Approx(0.04459));
   // Check importance values with negative event.
   TestImportance({{"PumpOne", {3, 0.0765, 0.1029, 0.1568, 2.613, 1.115}},
                   {"PumpTwo", {2, 0.057, 0.08948, 0.1532, 2.189, 1.098}},
@@ -285,24 +285,24 @@ TEST_F(RiskAnalysisTest, ImportanceNeg) {
 TEST_P(RiskAnalysisTest, ImportanceSingleEvent) {
   std::string tree_input = "tests/input/core/null_a.xml";
   settings.importance_analysis(true);
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  ASSERT_NO_THROW(analysis->Analyze());
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  REQUIRE_NOTHROW(analysis->Analyze());
   TestImportance({{"OnlyChild", {1, 1, 1, 1, 2, 0}}});
 }
 
 TEST_P(RiskAnalysisTest, ImportanceZeroProbability) {
   std::string tree_input = "tests/input/core/zero_prob.xml";
   settings.importance_analysis(true);
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  ASSERT_NO_THROW(analysis->Analyze());
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  REQUIRE_NOTHROW(analysis->Analyze());
   TestImportance({{"A", {1, 1, 0, 0, 0, 0}}});
 }
 
 TEST_P(RiskAnalysisTest, ImportanceOneProbability) {
   std::string tree_input = "tests/input/core/one_prob.xml";
   settings.importance_analysis(true);
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  ASSERT_NO_THROW(analysis->Analyze());
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  REQUIRE_NOTHROW(analysis->Analyze());
   TestImportance({{"A", {1, 1, 1, 1, 1, 0}}});
 }
 
@@ -311,9 +311,9 @@ TEST_F(RiskAnalysisTest, ImportanceRareEvent) {
   std::string with_prob = "tests/input/fta/importance_test.xml";
   // Probability calculations with the rare event approximation.
   settings.approximation("rare-event").importance_analysis(true);
-  ASSERT_NO_THROW(ProcessInputFiles({with_prob}));
-  ASSERT_NO_THROW(analysis->Analyze());
-  EXPECT_DOUBLE_EQ(0.012, p_total());  // Adjusted probability.
+  REQUIRE_NOTHROW(ProcessInputFiles({with_prob}));
+  REQUIRE_NOTHROW(analysis->Analyze());
+  CHECK(p_total() == Approx(0.012));  // Adjusted probability.
   TestImportance({{"PumpOne", {2, 0.12, 0.6, 0.624, 10.4, 2.5}},
                   {"PumpTwo", {2, 0.1, 0.5833, 0.6125, 8.75, 2.4}},
                   {"ValveOne", {2, 0.12, 0.4, 0.424, 10.6, 1.667}},
@@ -325,9 +325,9 @@ TEST_F(RiskAnalysisTest, Mcub) {
   std::string with_prob = "tests/input/fta/correct_tree_input_with_probs.xml";
   // Probability calculations with the MCUB approximation.
   settings.approximation("mcub").importance_analysis(true);
-  ASSERT_NO_THROW(ProcessInputFiles({with_prob}));
-  ASSERT_NO_THROW(analysis->Analyze());
-  EXPECT_DOUBLE_EQ(0.766144, p_total());
+  REQUIRE_NOTHROW(ProcessInputFiles({with_prob}));
+  REQUIRE_NOTHROW(analysis->Analyze());
+  CHECK(p_total() == Approx(0.766144));
 }
 
 // Apply the minimal cut set upper bound approximation for non-coherent tree.
@@ -336,9 +336,9 @@ TEST_F(RiskAnalysisTest, McubNonCoherent) {
   std::string with_prob = "tests/input/core/a_and_not_b.xml";
   // Probability calculations with the MCUB approximation.
   settings.approximation("mcub").probability_analysis(true);
-  ASSERT_NO_THROW(ProcessInputFiles({with_prob}));
-  ASSERT_NO_THROW(analysis->Analyze());
-  EXPECT_NEAR(0.10, p_total(), 1e-5);
+  REQUIRE_NOTHROW(ProcessInputFiles({with_prob}));
+  REQUIRE_NOTHROW(analysis->Analyze());
+  CHECK(p_total() == Approx(0.10));
 }
 
 // Test Monte Carlo Analysis
@@ -346,8 +346,8 @@ TEST_F(RiskAnalysisTest, McubNonCoherent) {
 TEST_P(RiskAnalysisTest, AnalyzeMC) {
   settings.uncertainty_analysis(true);
   std::string tree_input = "tests/input/fta/correct_tree_input_with_probs.xml";
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  ASSERT_NO_THROW(analysis->Analyze());
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  REQUIRE_NOTHROW(analysis->Analyze());
 }
 
 TEST_P(RiskAnalysisTest, AnalyzeProbabilityOverTime) {
@@ -355,25 +355,25 @@ TEST_P(RiskAnalysisTest, AnalyzeProbabilityOverTime) {
   settings.probability_analysis(true).time_step(24).mission_time(120);
   std::vector<double> curve = {0,        2.399e-4, 4.7989e-4,
                                7.197e-4, 9.595e-4, 1.199e-3};
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  ASSERT_NO_THROW(analysis->Analyze());
-  ASSERT_FALSE(analysis->results().empty());
-  ASSERT_TRUE(analysis->results().front().probability_analysis);
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  REQUIRE_NOTHROW(analysis->Analyze());
+  REQUIRE_FALSE(analysis->results().empty());
+  REQUIRE(analysis->results().front().probability_analysis);
   auto it = curve.begin();
   double time = 0;
   for (const std::pair<double, double>& p_vs_time :
        analysis->results().front().probability_analysis->p_time()) {
-    ASSERT_NE(curve.end(), it);
+    REQUIRE_FALSE(it == curve.end());
     if (time >= settings.mission_time()) {
-      EXPECT_EQ(settings.mission_time(), p_vs_time.second);
+      CHECK(p_vs_time.second == settings.mission_time());
     } else {
-      EXPECT_EQ(time, p_vs_time.second);
+      CHECK(p_vs_time.second == time);
     }
-    EXPECT_NEAR(*it, p_vs_time.first, *it * 0.001);
+    CHECK(p_vs_time.first == Approx(*it).epsilon(1e-3));
     time += settings.time_step();
     ++it;
   }
-  ASSERT_TRUE(time);
+  REQUIRE(time);
 }
 
 TEST_P(RiskAnalysisTest, AnalyzeSil) {
@@ -382,23 +382,24 @@ TEST_P(RiskAnalysisTest, AnalyzeSil) {
   double pfd_fractions[] = {1.142e-4, 1.0275e-3, 1.02796e-2,
                             0.1033,   0.88527,   0};
   double pfh_fractions[] = {2.74e-7, 2.466e-6, 2.466e-5, 2.466e-4, 0.999726, 0};
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  ASSERT_NO_THROW(analysis->Analyze());
-  ASSERT_FALSE(analysis->results().empty());
-  ASSERT_TRUE(analysis->results().front().probability_analysis);
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  REQUIRE_NOTHROW(analysis->Analyze());
+  REQUIRE_FALSE(analysis->results().empty());
+  REQUIRE(analysis->results().front().probability_analysis);
   const auto& prob_an = *analysis->results().front().probability_analysis;
-  EXPECT_NEAR(0.04255, prob_an.sil().pfd_avg, 0.00001);
-  EXPECT_NEAR(9.77e-6, prob_an.sil().pfh_avg, 1e-8);
+  CHECK(prob_an.sil().pfd_avg == Approx(0.04255).epsilon(1e-3));
+  CHECK(prob_an.sil().pfh_avg == Approx(9.77e-6).epsilon(1e-3));
   auto compare_fractions = [](const auto& sil_fractions, const auto& result,
                               const char* type) {
     auto it = std::begin(sil_fractions);
     for (const std::pair<const double, double>& result_bucket : result) {
-      ASSERT_NE(std::end(sil_fractions), it);
-      EXPECT_NEAR(*it, result_bucket.second, *it * 0.001)
-          << "The " << type << " bucket for " << result_bucket.first;
+      CAPTURE(type);
+      INFO("bucket: " + std::to_string(result_bucket.first));
+      REQUIRE_FALSE(it == std::end(sil_fractions));
+      CHECK(result_bucket.second == Approx(*it).epsilon(1e-3));
       ++it;
     }
-    ASSERT_EQ(std::end(sil_fractions), it);
+    REQUIRE(it == std::end(sil_fractions));
   };
   compare_fractions(pfd_fractions, prob_an.sil().pfd_fractions, "PFD");
   compare_fractions(pfh_fractions, prob_an.sil().pfh_fractions, "PFH");
@@ -407,41 +408,42 @@ TEST_P(RiskAnalysisTest, AnalyzeSil) {
 TEST_P(RiskAnalysisTest, AnalyzeEventTree) {
   const char* tree_input = "input/EventTrees/bcd.xml";
   settings.probability_analysis(true);
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  ASSERT_NO_THROW(analysis->Analyze());
-  EXPECT_EQ(1, analysis->event_tree_results().size());
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  REQUIRE_NOTHROW(analysis->Analyze());
+  CHECK(analysis->event_tree_results().size() == 1);
   const auto& results = sequences();
-  ASSERT_EQ(2, results.size());
+  REQUIRE(results.size() == 2);
   std::map<std::string, double> expected = {{"Success", 0.594},
                                             {"Failure", 0.406}};
   for (const auto& result : expected) {
-    ASSERT_TRUE(results.count(result.first)) << result.first;
-    EXPECT_DOUBLE_EQ(result.second, results.at(result.first)) << result.first;
+    INFO("state: " + result.first);
+    REQUIRE(results.count(result.first));
+    CHECK(results.at(result.first) == Approx(result.second));
   }
 }
 
 TEST_P(RiskAnalysisTest, AnalyzeTestEventDefault) {
   const char* tree_input = "tests/input/eta/test_event_default.xml";
   settings.probability_analysis(true);
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  ASSERT_NO_THROW(analysis->Analyze());
-  EXPECT_EQ(1, analysis->event_tree_results().size());
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  REQUIRE_NOTHROW(analysis->Analyze());
+  CHECK(analysis->event_tree_results().size() == 1);
   const auto& results = sequences();
-  ASSERT_EQ(1, results.size());
-  EXPECT_EQ("S", results.begin()->first);
-  EXPECT_DOUBLE_EQ(0.5, results.begin()->second);
+  REQUIRE(results.size() == 1);
+  CHECK(results.begin()->first == "S");
+  CHECK(results.begin()->second == Approx(0.5));
 }
 
 TEST_P(RiskAnalysisTest, AnalyzeTestInitatingEvent) {
   const char* tree_input = "tests/input/eta/test_initiating_event.xml";
   settings.probability_analysis(true);
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  ASSERT_NO_THROW(analysis->Analyze());
-  EXPECT_EQ(1, analysis->event_tree_results().size());
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  REQUIRE_NOTHROW(analysis->Analyze());
+  CHECK(analysis->event_tree_results().size() == 1);
   const auto& results = sequences();
-  ASSERT_EQ(1, results.size());
-  EXPECT_EQ("S", results.begin()->first);
-  EXPECT_DOUBLE_EQ(0.5, results.begin()->second);
+  REQUIRE(results.size() == 1);
+  CHECK(results.begin()->first == "S");
+  CHECK(results.begin()->second == Approx(0.5));
 }
 
 TEST_P(RiskAnalysisTest, AnalyzeTestFunctionalEvent) {
@@ -449,13 +451,15 @@ TEST_P(RiskAnalysisTest, AnalyzeTestFunctionalEvent) {
                               "tests/input/eta/test_functional_event_link.xml"};
   settings.probability_analysis(true);
   for (auto input : tree_input) {
-    ASSERT_NO_THROW(ProcessInputFiles({input}));
-    ASSERT_NO_THROW(analysis->Analyze()) << input;
-    EXPECT_EQ(1, analysis->event_tree_results().size()) << input;
+    REQUIRE_NOTHROW(ProcessInputFiles({input}));
+    CAPTURE(input);
+    REQUIRE_NOTHROW(analysis->Analyze());
+    CHECK(analysis->event_tree_results().size() == 1);
     const auto& results = sequences();
-    ASSERT_EQ(1, results.size()) << input;
-    EXPECT_EQ("S", results.begin()->first) << input;
-    EXPECT_DOUBLE_EQ(0.5, results.begin()->second) << input;
+    CAPTURE(input);
+    REQUIRE(results.size() == 1);
+    CHECK(results.begin()->first == "S");
+    CHECK(results.begin()->second == Approx(0.5));
   }
 }
 
@@ -466,9 +470,9 @@ TEST_F(RiskAnalysisTest, ReportIOError) {
   std::string tree_input = "tests/input/fta/correct_tree_input.xml";
   // Messing up the output file.
   std::string output = "abracadabra.cadabraabra/output.txt";
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  ASSERT_NO_THROW(analysis->Analyze());
-  EXPECT_THROW(Reporter().Report(*analysis, output), IOError);
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  REQUIRE_NOTHROW(analysis->Analyze());
+  CHECK_THROWS_AS(Reporter().Report(*analysis, output), IOError);
 }
 
 TEST_F(RiskAnalysisTest, ReportEmpty) {
@@ -580,57 +584,55 @@ TEST_F(RiskAnalysisTest, ReportAlignmentEventTree) {
 // NAND and NOR as a child cases.
 TEST_P(RiskAnalysisTest, ChildNandNorGates) {
   std::string tree_input = "tests/input/fta/children_nand_nor.xml";
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  ASSERT_NO_THROW(analysis->Analyze());
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  REQUIRE_NOTHROW(analysis->Analyze());
   if (settings.prime_implicants()) {
     std::set<std::set<std::string>> pi = {
         {"not PumpOne", "not PumpTwo", "not ValveOne"},
         {"not PumpOne", "not ValveTwo", "not ValveOne"}};
-    EXPECT_EQ(pi, products());
+    CHECK(products() == pi);
   } else {
-    EXPECT_EQ(kUnity, products());
+    CHECK(products() == kUnity);
   }
 }
 
 // Simple test for several house event propagation.
 TEST_P(RiskAnalysisTest, ManyHouseEvents) {
   std::string tree_input = "tests/input/fta/constant_propagation.xml";
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  ASSERT_NO_THROW(analysis->Analyze());
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  REQUIRE_NOTHROW(analysis->Analyze());
   std::set<std::set<std::string>> mcs = {{"A", "B"}};
-  EXPECT_EQ(mcs, products());
+  CHECK(products() == mcs);
 }
 
 // Simple test for several constant gate propagation.
 TEST_P(RiskAnalysisTest, ConstantGates) {
   std::string tree_input = "tests/input/fta/constant_gates.xml";
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  ASSERT_NO_THROW(analysis->Analyze());
-  EXPECT_EQ(kUnity, products());
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  REQUIRE_NOTHROW(analysis->Analyze());
+  CHECK(products() == kUnity);
 }
 
 // Mixed roles with undefined event types
 TEST_F(RiskAnalysisTest, UndefinedEventsMixedRoles) {
   std::string tree_input = "tests/input/fta/ambiguous_events_with_roles.xml";
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
-  ASSERT_NO_THROW(analysis->Analyze());
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}));
+  REQUIRE_NOTHROW(analysis->Analyze());
   std::set<std::set<std::string>> mcs = {
       {"C", "Ambiguous.Private.A", "Ambiguous.Private.B"},
       {"G", "Ambiguous.Private.A", "Ambiguous.Private.B"}};
-  EXPECT_EQ(mcs, products());
+  CHECK(products() == mcs);
 }
 
 // Extern function call check.
 TEST_P(RiskAnalysisTest, ExternFunctionProbability) {
   std::string tree_input = "tests/input/model/extern_full_check.xml";
   settings.probability_analysis(true);
-  ASSERT_NO_THROW(ProcessInputFiles({tree_input}, true));
-  ASSERT_NO_THROW(analysis->Analyze());
+  REQUIRE_NOTHROW(ProcessInputFiles({tree_input}, true));
+  REQUIRE_NOTHROW(analysis->Analyze());
   std::set<std::set<std::string>> mcs = {{"e1"}};
-  EXPECT_EQ(mcs, products());
-  EXPECT_DOUBLE_EQ(0.1, p_total());
+  CHECK(products() == mcs);
+  CHECK(p_total() == Approx(0.1));
 }
 
-}  // namespace test
-}  // namespace core
-}  // namespace scram
+}  // namespace scram::core::test
