@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017 Olzhas Rakhimov
+ * Copyright (C) 2017-2018 Olzhas Rakhimov
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
 /// @file
 /// Test helper functions.
 
-#ifndef SCRAM_TESTS_UTILITY_H_
-#define SCRAM_TESTS_UTILITY_H_
+#pragma once
 
 #include <string>
 
@@ -27,8 +26,7 @@
 
 namespace fs = boost::filesystem;
 
-namespace scram {
-namespace utility {
+namespace scram::utility {
 
 /// Generate unique file path for temporary files.
 inline fs::path GenerateFilePath(const std::string& prefix = "scram_test") {
@@ -36,7 +34,4 @@ inline fs::path GenerateFilePath(const std::string& prefix = "scram_test") {
   return fs::temp_directory_path() / unique_name;
 }
 
-}  // namespace utility
-}  // namespace scram
-
-#endif  // SCRAM_TESTS_UTILITY_H_
+}  // namespace scram::utility
